@@ -11,96 +11,87 @@ import re
 
 init()
 
-VARIABLE_RE = re.compile(r"""
+r"""
     \s*                    # Whitespace
     (\*{0,2}[a-zA-Z_0-9]+) # Valid characters for variable name, group is full name of variable
     \s*                    # Whitespace
     [=,]*                  # Variables are seperated by either = or ,
-""", re.VERBOSE)
+"""
+VARIABLE_RE = re.compile(r"\s*([*a-zA-Z_0-9]+)\s*[=,]*")
 # Regex to match variable name
 # Group 0 - Full match
 # Group 1 - Variable name
 
-FUNC_INFO_RE = re.compile(r"""
+r"""
     \(          # Opening parentheses of function defenition
         (.*)    # Variables etc.
     \)          # Closing parentheses of function defenition
     (           # Open capture group for return annotation
-        [ ]?    # Optional space before arrow
+        [ ]*    # Space before arrow
         ->      # Arrow denoting return annotation
-        [ ]?    # Optional space after arrow
+        [ ]*    # Space after arrow
         [^:]+   # The return annotation
                 # 
     )?:         # Close return annotation group, also
                 # make it optional and add colon to indicate
                 # the end of function definition.
-""", flags=re.DOTALL | re.VERBOSE)
+"""
+FUNC_INFO_RE = re.compile(
+    r"\((.*)\)( *-> *[^:]+)?:", re.DOTALL
+)
 # Regex to match variables and return annotation
 # from first parenthesis after function name until colon
 # Group 0 - Full match
 # Group 1 - Variables
 # Group 2 - Return annotation (if any)
 
-FIND_FUNC_DEF_RE = re.compile(r"""
+r"""
     ^                   # Start of line to not match `def` keyword insides string etc
     (?:                 # Open capture group for characters before `def`
         [ \t]           # Valid characters before `def` is spaces and tabs
         |               # or
         (?:             # Open capture group for `async` keyword
             async       # `async` can be before `def`
-        )               
+        )               #
     )*                  # Close capture group for chars before `def`
-    def                 # the `def` keyword
+      def[ ]            # the `def` keyword
     (                   # Open capture group for function name
         [a-zA-Z_0-9]+   # Valid function name characters
     )
     \(                  # First parentheses of function definition
-""", flags=re.MULTILINE | re.VERBOSE)
+"""
+FIND_FUNC_DEF_RE = re.compile(
+    r"^(?:[ \t]|(?:async))*def ([a-zA-Z_0-9]+)\(", re.MULTILINE
+)
 # Regex to find a function definition
 # Group 0 - Full match
 # Group 1 - Function name
 
-TRIPLE_Q_RE = re.compile(r"""
+r"""
     \"{3}   # Opening triple quotes
     (.*?)   # everything inside multiline comment
     \"{3}   # Closing triple quotes
-""", flags=re.DOTALL | re.VERBOSE)
+"""
+TRIPLE_Q_RE = re.compile(
+    r"\"{3}(.*?)\"{3}", re.DOTALL
+)
 # Regex for matching anything inside triple quotation marks (")
 # Group 0 - Full match
 # Group 1 - Text inside comment
 
-TRIPLE_A_RE = re.compile(r"""
+r"""
     \'{3}   # Opening triple apostrophes
     (.*?)   # everything inside multiline comment
     \'{3}   # Closing triple apostrophes
-""", flags=re.DOTALL | re.VERBOSE)
+"""
+TRIPLE_A_RE = re.compile(
+    r"\'{3}(.*?)\'{3}", re.DOTALL
+)
 # Regex for matching anything inside triple apostrophes (')
 # Group 0 - Full match
 # Group 1 - Text inside comment
 
-COMMENT_RE_Q = re.compile(r"""
-    (?s)              # the dot matches newlines too
-    (                 # open the capture group 1
-        "             # "
-        [^"\\]*       # all characters except a quote or a backslash
-                      # zero or more times
-        (?:           # open a non-capturing group
-            \\.       # a backslash and any character
-            [^"\\]*   # 
-        )*            # repeat zero or more times
-        "             # "
-    )                 # close the capture group 1
-    
-    |                 # OR
-    
-    #[^\n]*           # a sharp and zero or one characters that are not a newline.
-""", flags=re.VERBOSE | re.MULTILINE)
-# Regex for everything after "#" until line end
-# Group 0 - Full match
-# Group 1 - Empty
-
-
-""" # This regex doesn't work in verbose mode for some odd reason
+r"""
 (?s)              # the dot matches newlines too
 (                 # open the capture group 1
     ["']          # " or '
@@ -117,12 +108,15 @@ COMMENT_RE_Q = re.compile(r"""
 
 #[^\n]*           # a sharp and zero or one characters that are not a newline.
 """
-COMMENT_RE_A = re.compile(r"(?s)([\"'][^\"'\\]*(?:\\.[^\"'\\]*)*[\"'])|#[^\n]*", flags=re.MULTILINE)
+COMMENT_RE = re.compile(
+    r"(?s)([\"'][^\"'\\]*(?:\\.[^\"'\\]*)*[\"'])|#[^\n]*",
+    flags=re.MULTILINE
+)
 # Regex for everything after "#" until line end
 # Group 0 - Full match
 # Group 1 - Empty
 
-MAIN_RE = re.compile(r"""
+r"""
     ^(              # Line must start with whole match
         if +        # `if` and optional space
         __name__    # Match string
@@ -132,7 +126,10 @@ MAIN_RE = re.compile(r"""
         ['"]        # Match either quote or apostrophe
         [ ]*:       # Optional space after string and colon ending function defenition
     )
-""", flags=re.MULTILINE | re.VERBOSE)
+"""
+MAIN_RE = re.compile(
+    r"^(if +__name__ *== *('|\")__main__('|\") *:)", flags=re.MULTILINE
+)
 # Regex for matching line containing if __name__ == '__main__'
 # Group 0 - Full match
 # Group 1 - Whole line
@@ -170,7 +167,7 @@ def _split_vars(input_str: str) -> list:
             elif char == "]":
                 bracket_count -= 1
 
-    _last_var = input_str[last_read : len(input_str)]
+    _last_var = input_str[last_read: len(input_str)]
     if _last_var:
         output.append(_last_var)
     return output
@@ -188,7 +185,7 @@ def _get_function_def(start: int, input_string: str) -> str:
         if input_string[i] == ")":
             paren_count -= 1
         if input_string[i] == ":" and paren_count == 0:
-            return input_string[start : i + 1]
+            return input_string[start: i + 1]
         i += 1
     return ""
 
@@ -281,8 +278,7 @@ def _get_file_info(path: str, **options: ty.Dict[str, ty.Union[str, bool]]) -> l
     if not options["include_docstrings"]:
         _file_text = TRIPLE_Q_RE.sub(_doc, _file_text)
         _file_text = TRIPLE_A_RE.sub(_doc, _file_text)
-    _file_text = COMMENT_RE_Q.sub("", _file_text)
-    _file_text = COMMENT_RE_A.sub("", _file_text)
+    _file_text = COMMENT_RE.sub(lambda m: m.group(1) if m.group(1) else "", _file_text)
 
     if options["match_function"]:
         match_func = re.compile(options["match_function"])
@@ -481,7 +477,9 @@ def main(src: click.Path, **options: ty.Dict[str, ty.Union[str, bool]]) -> None:
 
                     if options["compact"]:
                         print(
-                            f"{fo.GREEN}{filename}{s.RESET_ALL}: Missing {fo.BLUE}{len(_output)}{s.RESET_ALL} annotations."
+                            f"{fo.GREEN}{filename}{s.RESET_ALL}:"
+                            f"Missing {fo.BLUE}{len(_output)}{s.RESET_ALL}"
+                            f" annotations."
                         )
                     else:
                         print(
@@ -498,7 +496,9 @@ def main(src: click.Path, **options: ty.Dict[str, ty.Union[str, bool]]) -> None:
 
                         if options["compact"]:
                             print(
-                                f"{fo.GREEN}{filename}{s.RESET_ALL}: Missing {fo.BLUE}{len(_output)}{s.RESET_ALL} annotations."
+                                f"{fo.GREEN}{filename}{s.RESET_ALL}:"
+                                f"Missing {fo.BLUE}{len(_output)}{s.RESET_ALL}"
+                                f" annotations."
                             )
                         else:
                             print(
@@ -509,9 +509,16 @@ def main(src: click.Path, **options: ty.Dict[str, ty.Union[str, bool]]) -> None:
     else:
         _output = _get_file_info(src[0], **options)
         if _output:
-            for f in _output:
-                count += 1
-                print(f)
+            if options["compact"]:
+                print(
+                    f"{fo.GREEN}{src[0]}{s.RESET_ALL}:"
+                    f"Missing {fo.BLUE}{len(_output)}{s.RESET_ALL}"
+                    f" annotations."
+                )
+            else:
+                for f in _output:
+                    count += 1
+                    print(f)
         else:
             print(f"The file '{src[0]}' aren't missing annotations")
 
